/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

/*******************************************************************
 *
 *  NAME:	GrowingQ.h
 *
 *  CLASS:
 *	CBigByteGrowingQueue definition & declaration
 *
 *  DESCRIPTION:
 *	Class declaration for a CBigByteQueue that automaticlly grows
 *	on EnQueue.  also adds an EnQueue that queues a string
 *
 *******************************************************************/

#ifndef _GROWINGQ_H_
#define _GROWINGQ_H_

#include "cbbqueue.h"
#include "cbqueue.h"

class CBigByteGrowingQueue: public CBigByteQueue
{
public:
    CBigByteGrowingQueue(UINT32 ulSize) :
	CBigByteQueue(ulSize) {}

    UINT32 EnQueue( void *pInBuffer, UINT32 ulItemCount ) 
    {
	if ( GetAvailableElements() < ulItemCount )
	{
	    HX_VERIFY(Grow(ulItemCount) == 1);
	}
	return CBigByteQueue::EnQueue(pInBuffer, ulItemCount );
    }
    UINT32 EnQueue( const char* pBuf )
    {
	return EnQueue((char*)pBuf, strlen(pBuf));
    }
};


class CByteGrowingQueue: public CByteQueue
{
public:
    CByteGrowingQueue(UINT16 nSize, UINT16 nGranularity = 1) :
	CByteQueue(nSize, nGranularity) {}

    UINT16 EnQueue( void *pInBuffer, UINT16 nItemCount ) 
    {
	if (GetAvailableElements() < nItemCount)
	{
	    HX_VERIFY(Grow(nItemCount) == 1);
	}

	return CByteQueue::EnQueue(pInBuffer, nItemCount);
    }
};

#endif // _GROWINGQ_H

