/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

#ifndef _IHXFGBUF_H_
#define _IHXFGBUF_H_

typedef _INTERFACE      IHXBuffer                      IHXBuffer;

/****************************************************************************
 * 
 *  Interface:
 *
 *	IHXEnumFragmentedBuffer
 *
 *  Purpose:
 *
 *	Basic opaque data storage buffer. Used in interfaces where 
 *	object ownership is best managed through COM style reference 
 *	counting.
 *
 *  IID_IHXEnumFragmentedBuffer:
 *
 *	{00002301-0901-11d1-8B06-00A024406D59}
 *
 */
DEFINE_GUID(IID_IHXEnumFragmentedBuffer,   0x00002301, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 0xa0, 0x24, 0x40, 0x6d, 0x59);

/*
 *  The IHXCommonClassFactory supports creating an instance
 *  of this object.
 */
#define CLSID_IHXEnumFragmentedBuffer IID_IHXEnumFragmentedBuffer

#undef  INTERFACE
#define INTERFACE   IHXEnumFragmentedBuffer

DECLARE_INTERFACE_(IHXEnumFragmentedBuffer, IUnknown)
{
    /*
     *	IUnknown methods
     */
    STDMETHOD(QueryInterface)	(THIS_
				REFIID riid,
				void** ppvObj) PURE;

    STDMETHOD_(ULONG32,AddRef)	(THIS) PURE;

    STDMETHOD_(ULONG32,Release)	(THIS) PURE;

    /*
     *	IHXEnumFragmentedBuffer methods
     */
    STDMETHOD(Reset)(THIS) PURE;
    STDMETHOD(Next)
    (
        THIS_
        UINT32          ulNumToReturn,
        IHXBuffer**    ppbufNext,
        UINT32*         pulNumReturned
    ) PURE;
    STDMETHOD(Skip)
    (
        THIS_ 
        UINT32 ulNumToSkip
    ) PURE;
    STDMETHOD(Clone)
    (
        THIS_ 
        IHXEnumFragmentedBuffer** ppefbNew
    ) PURE;

};


/****************************************************************************
 * 
 *  Interface:
 *
 *	IHXFragmentedBuffer
 *
 *  Purpose:
 *
 *	Basic opaque data storage buffer. Used in interfaces where 
 *	object ownership is best managed through COM style reference 
 *	counting.
 *
 *  IID_IHXFragmentedBuffer:
 *
 *	{00002300-0901-11d1-8B06-00A024406D59}
 *
 */
DEFINE_GUID(IID_IHXFragmentedBuffer, 0x00002300, 0x901, 0x11d1, 0x8b, 0x6, 0x0, 
			0xa0, 0x24, 0x40, 0x6d, 0x59);

/*
 *  The IHXCommonClassFactory supports creating an instance
 *  of this object.
 */
#define CLSID_IHXFragmentedBuffer IID_IHXFragmentedBuffer

#undef  INTERFACE
#define INTERFACE   IHXFragmentedBuffer

DECLARE_INTERFACE_(IHXFragmentedBuffer, IUnknown)
{
    /*
     *	IUnknown methods
     */
    STDMETHOD(QueryInterface)	(THIS_
				REFIID riid,
				void** ppvObj) PURE;

    STDMETHOD_(ULONG32,AddRef)	(THIS) PURE;

    STDMETHOD_(ULONG32,Release)	(THIS) PURE;

    /*
     *	IHXFragmentedBuffer methods
     */
    STDMETHOD(GetEnumerator)
    (
        THIS_ 
        IHXEnumFragmentedBuffer** ppefbNewEnum
    ) PURE;

    STDMETHOD(Prepend)
    (
        THIS_ 
        IHXBuffer* pBufferFrom, 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom
    ) PURE;
    STDMETHOD(Append)
    (
        THIS_ 
        IHXBuffer* pBufferFrom, 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom
    ) PURE;
    STDMETHOD(Insert)
    (
        THIS_ 
        IHXBuffer* pBufferFrom, 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom, 
        ULONG32 ulStartTo
    ) PURE;
    STDMETHOD(Replace)
    (
        THIS_ 
        IHXBuffer* pBufferFrom, 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom, 
        ULONG32 ulStartTo
    ) PURE;

    STDMETHOD(Get)
    (
        THIS_ 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom, 
        REF(UCHAR*) pData, 
        REF(ULONG32) ulLength
    ) PURE;
    STDMETHOD_(UCHAR*, GetBuffer)
    (
        THIS_ 
        ULONG32 ulStartFrom, 
        ULONG32 ulLengthFrom
    ) PURE;

};


#endif /* !_IHXFGBUF_H_ */

